@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2020 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -144,7 +144,9 @@ public:
    const char *GetSuggestedFileName() { return suggested_filename; }
    void SetSuggestedFileName(const char *f) { if(f) suggested_filename.set(f); }
    void AutoRename(bool yes=true) { auto_rename=yes; }
+   bool IsAutoRename() const { return auto_rename; }
    const char *UseTempFile(const char *);
+   bool ShouldRename() const;
 };
 
 class FileCopy : public SMTask
